# ChangePlanSubType

Use this field to choose the sub type for your change plan order action.  However, if you do not set this field, the field will be automatically generated by the system according to the following rules:  When the old and new rate plans are within the same Grading catalog group: * If the grade of new plan is greater than that of the old plan, this is an \"Upgrade\". * If the grade of new plan is less than that of the old plan, this is a \"Downgrade\". * If the grade of new plan equals that of the old plan, this is a \"Crossgrade\".  When the old and new rate plans are not in the same Grading catalog group, or either has no group, this is \"PlanChanged\". 

## Enum

* `UPGRADE` (value: `'Upgrade'`)

* `DOWNGRADE` (value: `'Downgrade'`)

* `CROSSGRADE` (value: `'Crossgrade'`)

* `PLANCHANGED` (value: `'PlanChanged'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


